@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package RT::Extension::NonWatcherRecipients;
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 =head1 NAME
 
@@ -33,6 +33,8 @@ so you know someone may need to be added:
 If you want the person to see correspondence, you can click the link and add
 them. If not, you can just ignore the message.
 
+You can choose between a text message or html formatted message.
+
 =head1 INSTALLATION
 
 =over
@@ -73,19 +75,25 @@ or add C<RT::Extension::NonWatcherRecipients> to your existing C<@Plugins> line.
 
 =head1 USAGE
 
-If you run the C<make initdb> step, a new global template called
-C<NonWatcherRecipients Admin Correspondence> is installed on your system.
-You can then select this template for any scrips that use the
-standard C<Admin Correspondence> template. We recommend the
-C<Admin Correspondence> template because you'll need RT privileges
-to add the user to the ticket.
+If you run the C<make initdb> step, two new global templates called
+C<NonWatcherRecipients Admin Correspondence> and
+C<NonWatcherRecipients Admin Correspondence in HTML> are installed on your
+system. You can then select one of these templates for any scrips that use the
+standard C<Admin Correspondence> or C<Admin Correspondence in HTML> templates.
+We recommend the C<Admin Correspondence> templates because you'll need RT
+privileges to add the user to the ticket.
 
-You can also add this to existing templates by adding the following
-to any template:
+You can also add these to existing templates by adding the following
+to any template for the plain text version:
 
     { RT::Extension::NonWatcherRecipients->FindRecipients(
         Transaction => $Transaction, Ticket => $Ticket ) }
 
+or adding the following for the html version:
+
+    { RT::Extension::NonWatcherRecipients->FindRecipients(
+        Transaction => $Transaction, Ticket => $Ticket, Format => 'text/html' ) }
+
 As described below, this method returns a message which is then inserted into
 your template.  Look at the installed template for an example.  You may also
 call the method and use the returned string however you'd like.
@@ -98,8 +106,13 @@ Search headers for recipients not included as watchers on the ticket
 and return a message to insert in the outgoing email to notify
 participants.
 
-Takes: (Transaction => $Transaction, Ticket => $Ticket)
-These are the objects provided in the RT template.
+Takes:
+
+    (Transaction => $Transaction, Ticket => $Ticket, Format => 'text/html')
+
+Transaction and Ticket are the objects provided in the RT template.
+Format is an optional parameter that accepts either 'text/plain' or 'text/html'
+and defaults to 'text/plain' if not specified.
 
 Returns: a message to insert in a template
 
@@ -107,9 +120,11 @@ Returns: a message to insert in a template
 
 sub FindRecipients {
     my $self = shift;
-    my %args = @_;
+    my %args = ( Format => 'text/plain',
+                 @_ );
     my $Transaction = $args{Transaction};
     my $Ticket = $args{Ticket};
+    my $Format = $args{Format};
     my $recipients; # List of recipients
     my $message = ""; # Message for template
 
@@ -125,27 +140,39 @@ sub FindRecipients {
     my %addr = %{ $att->Addresses };
     my $creator = $Transaction->CreatorObj->RealName || '';
 
+    my $newline = "\n";
+    if ( $Format eq 'text/html' ) {
+        $newline = "<br/>\n";
+    }
+
     # Show any extra recipients
     for my $hdr (qw(From To Cc RT-Send-Cc RT-Send-Bcc)) {
         my @new = grep { not $self->IsWatcher($_->address, $Ticket) } @{$addr{$hdr} || []};
-        $recipients .= "   $hdr: " . $self->Format(\@new) . "\n"
+        $recipients .= "   $hdr: " . $self->Format(\@new) . $newline
             if @new;
     }
-
     if ($recipients) {
-        $message = "The following people received a copy of this email "
-                 . "but are not on the ticket. You may want to add them "
-                 . "before replying: ${RT::WebURL}Ticket/ModifyPeople.html?id="
-                 . $Ticket->id . "\n\n$recipients";
+        my $href = "${RT::WebURL}Ticket/ModifyPeople.html?id=" . $Ticket->id;
+        if ( $Format eq 'text/html' ) {
+            $message = "The following people received a copy of this email "
+                     . "but are not on the ticket. You may want to "
+                     . '<a href="' . $href . '">add them</a> before replying.'
+                     . "$newline$newline$recipients";
+        }
+        else {
+            $message = "The following people received a copy of this email "
+                     . "but are not on the ticket. You may want to add them "
+                     . "before replying: $href$newline$newline$recipients";
+        }
     }
 
     # Show From if there's a different phrase; this catches name changes and "via RT"
     my @from = grep { ($_->phrase||'') ne $creator } @{$addr{From} || []};
-    $message = "   From: " . $self->Format(\@from) . ($message ? "\n\n$message" : "\n")
+    $message = "   From: " . $self->Format(\@from) . ($message ? "$newline$newline$message" : $newline)
         if @from;
 
     if ($message) {
-        my $sep  = "-" x 72;
+        my $sep  = $Format eq 'text/html' ? '<hr />' : "-" x 72;
         $message = "$sep\n$message$sep\n";
     }
 
@@ -191,7 +218,7 @@ or via the web at
 
 =head1 LICENSE AND COPYRIGHT
 
-This software is Copyright (c) 2013-2020 by Best Practical Solutions, LLC
+This software is Copyright (c) 2013-2022 by Best Practical Solutions, LLC
 
 This is free software, licensed under:
 
